@@ -37,8 +37,8 @@ BCstations
 stn_vector <- BCstations$station_id 
 stn_vector
 
-## -------------------------------------------------------------------------------------------------------------------------------------------------------------
-stations_dl()
+## ---- eval = FALSE--------------------------------------------------------------------------------------------------------------------------------------------
+#  stations_dl()
 
 ## -------------------------------------------------------------------------------------------------------------------------------------------------------------
 stations_meta()
